@@ -13,6 +13,7 @@ import pydantic
 
 from headless.types import IClient
 from headless.types import IResource
+from headless.types import IResponse
 from .resourcemeta import ResourceMeta
 from .resourcemetaclass import ResourceMetaclass
 
@@ -32,7 +33,24 @@ class Resource(IResource, metaclass=ResourceMetaclass):
     def get_list_url(cls, *params: Any) -> str:
         return cls._meta.get_list_url()
 
+    @classmethod
+    def get_next_url(
+        cls,
+        response: IResponse[Any, Any]
+    ) -> str | None:
+        """Return the next URL when paginating, or ``None`` if there is
+        no next URL.
+        """
+        raise NotImplementedError
+
     @classmethod
     def process_response(cls, action: str, data: dict[str, Any]) -> dict[str, Any]:
         """Process response data prior to parsing using the declared model."""
-        return data
\ No newline at end of file
+        return data
+
+    async def persist(self, client: IClient[Any, Any]):
+        await client.persist(
+            model=type(self),
+            instance=self
+        )
+        self._client = client
\ No newline at end of file
