@@ -10,4 +10,6 @@ import pydantic
 
 
 class IResource(pydantic.BaseModel):
-    pass
\ No newline at end of file
+
+    def get_persist_url(self) -> str:
+        raise NotImplementedError
\ No newline at end of file
